@@ -7,18 +7,26 @@ __all__ = [
     "ToSmiles",
     "CheckMol",
     "CheckSmiles",
+    "CheckAMSR",
     "Groups",
     "InitializeGroups",
     "ToTokens",
     "Morph",
-    "Sampler",
+    "Markov",
+    "Modifier",
+    "GetConformerAndEnergy",
+    "LSTMModel",
+    "__version__",
 ]
 
-from .version import __version__
-from .encode import FromMol, FromMolToTokens, FromSmiles, FromSmilesToTokens
+from .check import CheckAMSR, CheckMol, CheckSmiles
+from .conf import GetConformerAndEnergy
 from .decode import ToMol, ToSmiles
-from .check import CheckMol, CheckSmiles
+from .encode import FromMol, FromMolToTokens, FromSmiles, FromSmilesToTokens
 from .groups import Groups, InitializeGroups
-from .tokens import ToTokens
+from .lstm import LSTMModel
+from .markov import Markov
+from .modifier import Modifier
 from .morph import Morph
-from .sampler import Sampler
+from .tokens import ToTokens
+from .version import __version__
